@@ -11,8 +11,9 @@ use tree_sitter::{
 };
 
 use super::{Audit, AuditLoadError, audit_meta};
+use crate::finding::location::Locatable as _;
 use crate::finding::{Confidence, Finding, Severity};
-use crate::models::{JobExt as _, Step, StepCommon};
+use crate::models::{workflow::JobExt as _, workflow::Step};
 use crate::state::AuditState;
 use crate::utils;
 
