@@ -12,12 +12,11 @@ use github_actions_models::{
 };
 
 use super::{Audit, AuditLoadError, Job, audit_meta};
-use crate::models::Matrix;
 use crate::{
     AuditState,
     finding::{Confidence, Persona, Severity},
-    models::JobExt as _,
 };
+use crate::{finding::location::Locatable as _, models::workflow::Matrix};
 
 pub(crate) struct SelfHostedRunner;
 
@@ -37,7 +36,7 @@ impl Audit for SelfHostedRunner {
 
     fn audit_workflow<'doc>(
         &self,
-        workflow: &'doc crate::models::Workflow,
+        workflow: &'doc crate::models::workflow::Workflow,
     ) -> Result<Vec<crate::finding::Finding<'doc>>> {
         let mut results = vec![];
 
