@@ -33,6 +33,18 @@ fn test_github_output() -> Result<()> {
     Ok(())
 }
 
+#[test]
+fn anonymous_definition() -> Result<()> {
+    insta::assert_snapshot!(
+        zizmor()
+            .input(input_under_test("anonymous-definition.yml"))
+            .args(["--persona=pedantic"])
+            .run()?
+    );
+
+    Ok(())
+}
+
 #[test]
 fn artipacked() -> Result<()> {
     insta::assert_snapshot!(
@@ -58,6 +70,13 @@ fn artipacked() -> Result<()> {
             .run()?
     );
 
+    insta::assert_snapshot!(
+        zizmor()
+            .input(input_under_test("artipacked/demo-action/action.yml"))
+            .args(["--persona=auditor"])
+            .run()?
+    );
+
     Ok(())
 }
 
@@ -242,6 +261,25 @@ fn unpinned_uses() -> Result<()> {
     Ok(())
 }
 
+#[test]
+fn use_trusted_publishing() -> Result<()> {
+    insta::assert_snapshot!(
+        zizmor()
+            .input(input_under_test("use-trusted-publishing.yml"))
+            .run()?
+    );
+
+    insta::assert_snapshot!(
+        zizmor()
+            .input(input_under_test(
+                "use-trusted-publishing/demo-action/action.yml"
+            ))
+            .run()?
+    );
+
+    Ok(())
+}
+
 #[test]
 fn insecure_commands() -> Result<()> {
     insta::assert_snapshot!(
@@ -358,6 +396,23 @@ fn template_injection() -> Result<()> {
             .run()?
     );
 
+    insta::assert_snapshot!(
+        zizmor()
+            .input(input_under_test(
+                "template-injection/issue-883-repro/action.yml"
+            ))
+            .run()?
+    );
+
+    insta::assert_snapshot!(
+        zizmor()
+            .input(input_under_test(
+                "template-injection/multiline-expression.yml"
+            ))
+            .args(["--persona=pedantic"])
+            .run()?
+    );
+
     Ok(())
 }
 
@@ -702,6 +757,13 @@ fn forbidden_uses() -> Result<()> {
 fn obfuscation() -> Result<()> {
     insta::assert_snapshot!(zizmor().input(input_under_test("obfuscation.yml")).run()?);
 
+    insta::assert_snapshot!(
+        zizmor()
+            .input(input_under_test("obfuscation/computed-indices.yml"))
+            .args(["--persona=pedantic"])
+            .run()?
+    );
+
     Ok(())
 }
 
